@@ -8,12 +8,9 @@ try:                        # pragma: no cover
     import configparser
 except:                     # pragma: no cover
     import ConfigParser as configparser
-try:                        # pragma: no cover
-    import coverage
-    coverage_version = "Coverage {}".format(coverage.__version__)
-except:                     # pragma: no cover
-    coverage = None
-    coverage_version = "Coverage Not Installed"
+
+import coverage              # pragma: no cover
+coverage_version = "Coverage {}".format(coverage.__version__) # pragma: no cover
 
 import copy                  # pragma: no cover
 import logging               # pragma: no cover
@@ -128,33 +125,8 @@ def parseArguments(argv=None):  # pragma: no cover
 
                 CONFIG FILES
 
-
-                  Configuration settings are resolved in this order, with settings found later
-                  in the resolution chain overwriting earlier settings (last setting wins).
-
-                  1) $HOME/.green
-                  2) A config file specified by the environment variable $GREEN_CONFIG
-                  3) setup.cfg in the current working directory of test run
-                  4) .green in the current working directory of the test run
-                  5) A config file specified by the command-line argument "--config FILE"
-                  6) Command-line arguments.
-
-                  Any arguments specified in more than one place will be overwritten by the
-                  value of the LAST place the setting is seen.  So, for example, if a setting
-                  is turned on in ~/.green and turned off by a command-line argument, then the
-                  setting will be turned off.
-
-                  Config file format syntax is "option = value" on separate lines.  "option" is
-                  the same as the long options above, just without the "--".
-
-                  Most values should be "True" or "False".  Accumulated values (verbose, debug)
-                  should be specified as integers ("-vv" would be "verbose = 2").
-
-                  Example:
-
-                    verbose       = 2
-                    logging       = True
-                    omit-patterns = myproj*,*prototype*
+                  For documentation on config files, please see
+                  https://github.com/CleanCut/green#config-files
                 """.rstrip()),
             formatter_class=argparse.RawDescriptionHelpFormatter)
 
@@ -536,13 +508,6 @@ def mergeConfig(args, testing=False):  # pragma: no cover
         new_args.run_coverage = True
 
     if new_args.run_coverage:
-        if not coverage:
-            print(
-                "Fatal: The 'coverage' module is not installed.  Have you "
-                "run 'pip install coverage' ???")
-            args.shouldExit = True
-            args.exitCode = 3
-            return args
         if not testing:
             cov = coverage.coverage(data_file='.coverage', omit=omit_patterns,
                                     include=new_args.include_patterns)
